@@ -1,6 +1,9 @@
 import logging,logging.handlers
-import traceback,imp
-from StringIO import StringIO
+import traceback,imp,sys
+if sys.version_info[0]==2:
+	from StringIO import StringIO
+elif sys.version_info[0]>=3:
+	from io import StringIO
 from os.path import join
 
 
