@@ -3,6 +3,7 @@
 
 import xml.dom.minidom as minidom
 import pprint,re,os,sys
+from pysite.compat import PORTABLE_STRING
 
 def parse_ts(ts_fname):
 	doc = minidom.parse(open(ts_fname))
@@ -21,7 +22,7 @@ def parse_ts(ts_fname):
 			if source not in tr_dict[context]:
 				tr_dict[context][source] = {}
 
-			comment = u''
+			comment = PORTABLE_STRING('')
 			c_elem = msg_elem.getElementsByTagName('comment')
 			if len(c_elem):
 				comment = c_elem[0].childNodes[0].data
